@@ -15,26 +15,26 @@
 exr_result_t
 exr_attr_string_init (exr_context_t ctxt, exr_attr_string_t* s, int32_t len)
 {
-    exr_attr_string_t nil = { 0 };
-    INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
+    exr_attr_string_t nil = {0};
+    if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
 
     if (len < 0)
-        return pctxt->print_error (
-            pctxt,
+        return ctxt->print_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Received request to allocate negative sized string (%d)",
             len);
 
     if (!s)
-        return pctxt->report_error (
-            pctxt,
+        return ctxt->report_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Invalid reference to string object to initialize");
 
     *s     = nil;
-    s->str = (char*) pctxt->alloc_fn ((size_t) (len + 1));
+    s->str = (char*) ctxt->alloc_fn ((size_t) (len + 1));
     if (s->str == NULL)
-        return pctxt->standard_error (pctxt, EXR_ERR_OUT_OF_MEMORY);
+        return ctxt->standard_error (ctxt, EXR_ERR_OUT_OF_MEMORY);
     s->length     = len;
     s->alloc_size = len + 1;
     return EXR_ERR_SUCCESS;
@@ -46,25 +46,25 @@ exr_result_t
 exr_attr_string_init_static_with_length (
     exr_context_t ctxt, exr_attr_string_t* s, const char* v, int32_t len)
 {
-    exr_attr_string_t nil = { 0 };
-    INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
+    exr_attr_string_t nil = {0};
+    if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
 
     if (len < 0)
-        return pctxt->print_error (
-            pctxt,
+        return ctxt->print_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Received request to allocate negative sized string (%d)",
             len);
 
     if (!v)
-        return pctxt->report_error (
-            pctxt,
+        return ctxt->report_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Invalid static string argument to initialize");
 
     if (!s)
-        return pctxt->report_error (
-            pctxt,
+        return ctxt->report_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Invalid reference to string object to initialize");
 
@@ -88,9 +88,9 @@ exr_attr_string_init_static (
         fulllen = strlen (v);
         if (fulllen >= (size_t) INT32_MAX)
         {
-            INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
-            return pctxt->report_error (
-                pctxt,
+            if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
+            return ctxt->report_error (
+                ctxt,
                 EXR_ERR_INVALID_ARGUMENT,
                 "Invalid string too long for attribute");
         }
@@ -106,11 +106,11 @@ exr_attr_string_create_with_length (
     exr_context_t ctxt, exr_attr_string_t* s, const char* d, int32_t len)
 {
     exr_result_t rv;
-    INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
+    if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
 
     if (!s)
-        return pctxt->report_error (
-            pctxt,
+        return ctxt->report_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Invalid (NULL) arguments to string create with length");
 
@@ -125,13 +125,18 @@ exr_attr_string_create_with_length (
 #ifdef _MSC_VER
 #    pragma warning(push)
 #    pragma warning(disable : 4996)
+#elif defined(__GNUC__)
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Wstringop-truncation"
 #endif
             if (d)
-                strncpy (outs, d, (size_t)len);
+                strncpy (outs, d, (size_t) len);
             else
-                memset (outs, 0, (size_t)len);
+                memset (outs, 0, (size_t) len);
 #ifdef _MSC_VER
 #    pragma warning(pop)
+#elif defined(__GNUC__)
+#    pragma GCC diagnostic pop
 #endif
         }
         outs[len] = '\0';
@@ -144,16 +149,15 @@ exr_attr_string_create_with_length (
 exr_result_t
 exr_attr_string_create (exr_context_t ctxt, exr_attr_string_t* s, const char* d)
 {
-    size_t  fulllen = 0;
-    int32_t len = 0;
+    int32_t len     = 0;
     if (d)
     {
-        fulllen = strlen (d);
+        size_t  fulllen = strlen (d);
         if (fulllen >= (size_t) INT32_MAX)
         {
-            INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
-            return pctxt->report_error (
-                pctxt,
+            if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
+            return ctxt->report_error (
+                ctxt,
                 EXR_ERR_INVALID_ARGUMENT,
                 "Invalid string too long for attribute");
         }
@@ -168,17 +172,17 @@ exr_result_t
 exr_attr_string_set_with_length (
     exr_context_t ctxt, exr_attr_string_t* s, const char* d, int32_t len)
 {
-    INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
+    if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
 
     if (!s)
-        return pctxt->report_error (
-            pctxt,
+        return ctxt->report_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Invalid string argument to string set");
 
     if (len < 0)
-        return pctxt->print_error (
-            pctxt,
+        return ctxt->print_error (
+            ctxt,
             EXR_ERR_INVALID_ARGUMENT,
             "Received request to assign a negative sized string (%d)",
             len);
@@ -189,12 +193,15 @@ exr_attr_string_set_with_length (
         char* sstr;
 
         s->length = len;
-        sstr = EXR_CONST_CAST (char*, s->str);
+        sstr      = EXR_CONST_CAST (char*, s->str);
         if (len > 0)
         {
 #ifdef _MSC_VER
 #    pragma warning(push)
 #    pragma warning(disable : 4996)
+#elif defined(__GNUC__)
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Wstringop-truncation"
 #endif
             if (d)
                 strncpy (sstr, d, (size_t) len);
@@ -202,6 +209,8 @@ exr_attr_string_set_with_length (
                 memset (sstr, 0, (size_t) len);
 #ifdef _MSC_VER
 #    pragma warning(pop)
+#elif defined(__GNUC__)
+#    pragma GCC diagnostic pop
 #endif
         }
         sstr[len] = '\0';
@@ -217,15 +226,15 @@ exr_result_t
 exr_attr_string_set (exr_context_t ctxt, exr_attr_string_t* s, const char* d)
 {
     size_t  fulllen = 0;
-    int32_t len = 0;
+    int32_t len     = 0;
     if (d)
     {
         fulllen = strlen (d);
         if (fulllen >= (size_t) INT32_MAX)
         {
-            INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
-            return pctxt->report_error (
-                pctxt,
+            if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
+            return ctxt->report_error (
+                ctxt,
                 EXR_ERR_INVALID_ARGUMENT,
                 "Invalid string too long for attribute");
         }
@@ -239,13 +248,13 @@ exr_attr_string_set (exr_context_t ctxt, exr_attr_string_t* s, const char* d)
 exr_result_t
 exr_attr_string_destroy (exr_context_t ctxt, exr_attr_string_t* s)
 {
-    INTERN_EXR_PROMOTE_CONTEXT_OR_ERROR (ctxt);
+    if (!ctxt) return EXR_ERR_MISSING_CONTEXT_ARG;
 
     if (s)
     {
-        exr_attr_string_t nil = { 0 };
+        exr_attr_string_t nil = {0};
         if (s->str && s->alloc_size > 0)
-            pctxt->free_fn ((char*) (uintptr_t) s->str);
+            ctxt->free_fn ((char*) (uintptr_t) s->str);
         *s = nil;
     }
     return EXR_ERR_SUCCESS;
